Puts two regex layout tests back on the DumpRenderTree skipped list

fast/regex/test1.html and fast/regex/slow.html were removed from the skipped
list in https://android-git.corp.google.com/g/#change,43908

However, they cause DumpRenderTree to hang when run with V8, so are added back
to the list pending further investigation.

Bug: 2509394
Change-Id: I83c361c99fcd61e940a169f1ed00614529af48ff
diff --git a/tests/DumpRenderTree/src/com/android/dumprendertree/FileFilter.java b/tests/DumpRenderTree/src/com/android/dumprendertree/FileFilter.java
index eecd00a..e3486a0 100644
--- a/tests/DumpRenderTree/src/com/android/dumprendertree/FileFilter.java
+++ b/tests/DumpRenderTree/src/com/android/dumprendertree/FileFilter.java
@@ -24,9 +24,8 @@
     private static final String LOGTAG = "FileFilter";
 
     // Returns whether we should ignore this test and skip running it.
     // Currently we use this only for tests that crash the browser.
     // TODO: Once these crashes are fixed, we should probably eliminate this
     // method, as no test should crash.
     public static boolean ignoreTest(String file) {
         for (int i = 0; i < ignoreTestList.length; i++) {
             if (file.endsWith(ignoreTestList[i])) {
@@ -74,6 +73,8 @@
 
     static final String[] ignoreTestList = {
         "fast/js/regexp-charclass-crash.html", // RegExp is too large, causing OOM
+        "fast/regex/test1.html", // Causes DumpRenderTree to hang with V8
+        "fast/regex/slow.html", // Causes DumpRenderTree to hang with V8
         "editing/selection/move-left-right.html" // Causes DumpRenderTree to hang
     };
@@ -24,9 +24,8 @@
 
     // Returns whether we should ignore this test and skip running it.
-    // Currently we use this only for tests that crash the browser.
-    // TODO: Once these crashes are fixed, we should probably eliminate this
-    // method, as no test should crash.
+    // Currently we use this only for tests that crash or hang DumpRenderTree.
+    // TODO: Fix these and eliminate this method.
     public static boolean ignoreTest(String file) {
         for (int i = 0; i < ignoreTestList.length; i++) {